
# Type: is_usage_slot


True means that this slot was defined in a slot_usage situation

URI: [meta:is_usage_slot](https://w3id.org/biolink/biolinkml/meta/is_usage_slot)


## Domain and Range

[SlotDefinition](SlotDefinition.md) ->  <sub>OPT</sub> [Boolean](types/Boolean.md)

## Parents


## Children


## Used by

 * [SlotDefinition](SlotDefinition.md)
